/* --COPYRIGHT--,BSD
 * Copyright (c) 2015, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//****************************************************************************
//
// HAL_I2C.h - Prototypes of hardware abstraction layer for I2C between
//             MSP430 and slave device
//
//****************************************************************************

#ifndef __HAL_I2C_H_
#define __HAL_I2C_H_

#include <driverlib.h>

#define I2C_BASE            EUSCI_B1_BASE

#ifdef USE_I2C_ON_PORT_4

#define I2C_SCL_PORT        GPIO_PORT_P4
#define I2C_SCL_PIN         GPIO_PIN1

#define I2C_SDA_PORT        GPIO_PORT_P4
#define I2C_SDA_PIN         GPIO_PIN0

#else

#define I2C_SCL_PORT        GPIO_PORT_P4
#define I2C_SCL_PIN         GPIO_PIN1

#define I2C_SDA_PORT        GPIO_PORT_P4
#define I2C_SDA_PIN         GPIO_PIN0

#endif

#define I2C_SELECT_FUNCTION GPIO_SECONDARY_MODULE_FUNCTION

/***************************************************************************//**
 * @brief  Configures GPIO for I2C
 * @param  none
 * @return none
 *
 ******************************************************************************/
void I2C_initGPIO(void);

/***************************************************************************//**
 * @brief  Configures I2C
 * @param  none
 * @return none
 *
 ******************************************************************************/
void I2C_init(void);

/***************************************************************************//**
 * @brief  Writes data to the slave device
 * @param  pointer  Address of register you want to modify
 * @param  writeByte Data to be written to the specified register
 * @return boolean indicating success or failure
 *
 ******************************************************************************/
bool I2C_write8(unsigned char pointer,
                unsigned char writeByte,
                unsigned int timeout);

/***************************************************************************//**
 * @brief  Writes data to the slave device
 * @param  pointer  Address of register you want to modify
 * @param  writeWord Data to be written to the specified register
 * @return boolean indicating success or failure
 *
 ******************************************************************************/
bool I2C_write16(unsigned char pointer,
                 unsigned short writeWord,
                 unsigned int timeout);

/***************************************************************************//**
 * @brief  Reads data from the slave device
 * @param  pointer Address of register to read from
 * @param pointer Address where to store Register contents
 * @return boolean indicating success or failure
 *
 ******************************************************************************/
bool I2C_read8(unsigned char pointer,
               char *result,
               unsigned int timeout);

/***************************************************************************//**
 * @brief  Reads data from the slave device
 * @param  pointer Address of register to read from
 * @param pointer Address where to store Register contents
 *
 * @return boolean indicating success or failure
 *
 ******************************************************************************/
bool I2C_read16(unsigned char pointer,
                short *result,
                unsigned int timeout);


/***************************************************************************//**
 * @brief  Reads array of data from the slave device
 * @param array the address of the array where to store the data
 *              the first element of the array is the address of the first
 *              element to read from slave device
 * @param numItems the number of items to retrieve from the slave device.
 * @return boolean indicating success or failure
 *
 ******************************************************************************/
bool I2C_writeArray(unsigned char *array,
                    unsigned int numItems,
                    unsigned int timeout);


/***************************************************************************//**
 * @brief  Reads array of data from the slave device
 * @param array the address of the array where to store the data
 *              the first element of the array is the address of the first
 *              element to read from slave device
 * @param numItems the number of items to retrieve from the slave device.
 * @return boolean indicating success or failure
 *
 ******************************************************************************/
bool I2C_readArray(unsigned char *array,
                   unsigned int numItems,
                   unsigned int timeout);

/***************************************************************************//**
 * @brief  set the slave address of the slave device
 * @param slaveAdr the 7 bit slave address of the slave device
 *
 ******************************************************************************/
void I2C_setslave(unsigned short slaveAdr);

#endif /* __HAL_I2C_H_ */
